is.overlap: Region overlap test

View source: R/misc.R

is.overlapR Documentation

Region overlap test

Description

Test if two regions are overlapping.

Usage

  is.overlap(x,y)

Arguments

x

a vector of two numeric values specifying the start and end positions of the first region.

y

a vector of two numeric values specifying the start and end positions of the second region

Value

Logic test output.

Author(s)

Minghui Wang <m.h.wang@live.com>

Examples

is.overlap(c(10,100),c(90,120))
is.overlap(c(10,100),c(110,120))

NetWeaver documentation built on July 15, 2026, 1:06 a.m.