| rc.plot.area | R Documentation |
Create new graphics frame for circle plot .
rc.plot.area(size=1, oma=rep(0,4), mar=rep(0,4))
size |
a value between 0 to 1, specifying the effective size of the circle plot area in the current window. The smaller the |
oma |
A vector of the form |
mar |
A numerical vector of the form |
After setting up, the extremes of the user coordinates of the plotting region can be found out by par('usr').
Minghui Wang <m.h.wang@live.com>
rc.initialize, rc.reset.params
#This is not to be run alone. Please see tutorial vignette("netweaver") for usage.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.