- track.ids
vector, two integers specifying the two tacks for plotting chromosome name and cyto band respectively.
- plot.band
logic, whether to plot ideogram cyto band.
- plot.chromosome.id
logic, whether to plot chromosome id.
- chrom.alias
NULL or a chromosome named vector of alias.
- color.chromosome.id
NULL or a chromosome named vector of colors.
- cex.text
numeric, scale of text.
- track.border
the color to draw the track border. Use NA to omit borders.
- polygon.border
the color to draw the polygon border. See explanation for polygon.
- las
numeric value in 0,1,2,3; the style of chromosome labels. 0, always parallel to the track [default]; 1, always horizontal; 2, always perpendicular to the track; 3, always vertical.
- custom.track.height
NULL or numeric, specifying customized track height when plotting cyto band.