Plot histogram or barplot that overlaps with multiple chromosomes.
rc.plot.mHistogram(Data, track.id, data.col, color.col=NULL, color.gradient=NULL,
fixed.height=FALSE, track.color=NA, track.border=NULL, polygon.border=NULL,
custom.track.height=NULL, max.value=NULL)
data.frame of at least four columns. See Details.
integer, the track number for plotting.
integer or character string, specifies the column of data.
integer or character string, specifies the column of colors.
a vector of gradient colors.
logical, whether to fix the histogram height, resulting in heat-map if TRUE.
NA or color code for the track background.
the color to draw the track border. Use NA to omit borders.
the color to draw the polygon border. See explanation for polygon.
NULL or numeric, specifying customized track height to overwrite the default. See rc.get.params for default value.
NULL or numeric, specifying the maximum data value for normalization. Default NULL, get max from data column data.col.
Minghui Wang <m.h.wang@live.com>
Data must have at least four columns: Chr1, Start1, Chr2 and End2, specifying the chromosomes and positions for the start and end points. Additional columns may be used to specify the data, color, etc.
If color.gradient is not NULL, it will supersede color.col.
rc.plot.link, rc.plot.histogram
#This is not to be run alone. Please see tutorial vignette("netweaver") for usage.
Run the code above in your browser using DataLab