rc.plot.track.id: Plot Track Id
Description
Plot labels in designated tracks.
Usage
rc.plot.track.id(track.id, labels=NULL, degree=0,
col='black', custom.track.height=NULL, ...)
Arguments
- track.id
a vector of integers, specifying the tracks for plotting id.
- labels
NULL or a vector of character string, specifying the text to be written.
- degree
the angle of the arc rotation.
- col
color for the text.
- custom.track.height
NULL or numeric, specifying customized track height.
- ...
further graphical parameters (from par), such as srt and family.
Author
Minghui Wang <m.h.wang@live.com>
Details
If labels is NULL, values of track.id will be used as text labels.
See Also
rc.plot.histogram, rc.plot.track
Examples
Run this code#This is not to be run alone. Please see tutorial vignette("netweaver") for usage.
Run the code above in your browser using DataLab