Learn R Programming

NetWeaver (version 1.0.0)

is.overlap: Region overlap test

Description

Test if two regions are overlapping.

Usage

is.overlap(x,y)

Value

Logic test output.

Arguments

x

a vector of two numeric values specifying the start and end positions of the first region.

y

a vector of two numeric values specifying the start and end positions of the second region

Author

Minghui Wang <m.h.wang@live.com>

Examples

Run this code
is.overlap(c(10,100),c(90,120))
is.overlap(c(10,100),c(110,120))

Run the code above in your browser using DataLab