powered by
Test if two regions are overlapping.
is.overlap(x,y)
Logic test output.
a vector of two numeric values specifying the start and end positions of the first region.
a vector of two numeric values specifying the start and end positions of the second region
Minghui Wang <m.h.wang@live.com>
is.overlap(c(10,100),c(90,120)) is.overlap(c(10,100),c(110,120))
Run the code above in your browser using DataLab