Learn R Programming

NetWeaver (version 1.0.0)

rc.plot.area: Setup Plot Area

Description

Create new graphics frame for circle plot .

Usage

rc.plot.area(size=1, oma=rep(0,4), mar=rep(0,4))

Arguments

size

a value between 0 to 1, specifying the effective size of the circle plot area in the current window. The smaller the size, the larger the blank area around the circle plot.

oma

A vector of the form c(bottom, left, top, right) giving the size of the outer margins in lines of text.

mar

A numerical vector of the form c(bottom, left, top, right) which gives the number of lines of margin to be specified on the four sides of the plot.

Author

Minghui Wang <m.h.wang@live.com>

Details

After setting up, the extremes of the user coordinates of the plotting region can be found out by par('usr').

See Also

rc.initialize, rc.reset.params

Examples

Run this code
#This is not to be run alone. Please see tutorial vignette("netweaver") for usage.

Run the code above in your browser using DataLab